use cgmath::{Deg, Point3};
use galactica_content::TextureHandle;

#[derive(Debug, Clone)]
pub struct Sprite {
	/// The sprite texture to draw
	pub texture: TextureHandle,

	/// This object's position, in world coordinates.
	pub pos: Point3<f32>,

	/// The size of this sprite,
	/// given as height in world units.
	pub size: f32,

	/// This sprite's rotation
	/// (relative to north, measured ccw)
	pub angle: Deg<f32>,

	/// Sprites that should be drawn relative to this sprite.
	pub children: Option<Vec<SubSprite>>,
}

#[derive(Debug, Clone)]
pub struct SubSprite {
	/// The sprite texture to draw
	pub texture: TextureHandle,

	/// This object's position, in world coordinates.
	/// This is relative to this sprite's parent.
	pub pos: Point3<f32>,

	/// The size of this sprite,
	/// given as height in world units.
	pub size: f32,

	/// This sprite's rotation
	/// (relative to north, measured ccw)
	/// Just as position, this is relative to this
	/// subsprite's parent sprite.
	pub angle: Deg<f32>,
}
